<template>
  <div class="mod-config">
    <basic-container>
      <ttable
        :table="table"
        @handleSelectionChange="handleSelectionChange"
        :uploadInfo="uploadInfo"
        :isShowHide="true"
        :prelang="prelang"
        :options="options"
        :bottomOffset="125"
        :ajaxFun="ajaxFun"
        ref="detectionrulesTable"
      >
        <template #toolbar></template>
      </ttable>
      <!-- 弹窗, 新增 / 修改 -->
      <table-form
        v-if="addOrUpdateVisible"
        ref="addOrUpdate"
        @refreshDataList="getData"
      ></table-form>
    </basic-container>
  </div>
</template>

<script>
import {
  fetchListTestApplyRule,
  delTestApplyRule
} from '@/api/quality/detectionrules'
import TableForm from './rule-form'
import { mapGetters } from 'vuex'
import ttable from '@/views/common/ztt-table.vue'
import { remote } from '../../../api/admin/dict'

export default {
  data() {
    return {
      ajaxFun: fetchListTestApplyRule,
      addOrUpdateVisible: false,
      multipleSelection: [],
      uploadInfo: {
        // 是否展示上传EXCEL以及对应的url
        isShow: false,
        url: ''
      },
      prelang: 'detectionrules',
      options: {
        height: 300, // 默认高度-为了表头固定
        stripe: true, // 是否为斑马纹 table
        highlightCurrentRow: false, // 是否要高亮当前行
        border: true, // 是否有纵向边框
        lazy: false, // 是否需要懒加载
        fit: true, // 列的宽度是否自撑开
        multiSelect: true, //
        seqNo: true,
        isShowHide: true, // 是否显示显影按钮
        isSearch: false, // 高级查询按钮
        isRefresh: true, // 是否显示刷新按钮
        defaultOrderBy: { column: 'id', direction: 'desc' }
      },
      table: {
        total: 0,
        currentPage: 1,
        pageSize: 20,
        data: [],
        // 标题
        column: [
          // 规则编号
          {
            minWidth: '30',
            prop: 'ruleNo',
            label: '规则编号',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text',
            render: { fun: this.addOrUpdateHandle }
          },
          // 规则名称
          {
            minWidth: '120',
            prop: 'ruleName',
            label: '规则名称',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          // 工序编号
          {
            minWidth: '140',
            prop: 'operationNo',
            label: '工序编号',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          // 工序名称
          {
            minWidth: '140',
            prop: 'operationName',
            label: '工序名称',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          // 检测方式
          {
            minWidth: '140',
            prop: 'inspectionType',
            label: '检测方式',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'select',
            formatter: this.getMaterialTypeType,
            optList: () => {
              return this.getMaterialTypeList()
            }
          },
          // 备注
          {
            minWidth: '140',
            prop: 'remark',
            label: '备注',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          }
        ],
        toolbar: [
          {
            text: '新增',
            type: 'primary',
            fun: this.addOrUpdateHandle
          }
        ],
        operator: [
          {
            text: '编辑',
            type: 'text',
            size: 'small',
            fun: this.addOrUpdateHandle
          },
          {
            text: '删除',
            type: 'text',
            size: 'small',
            fun: this.deleteHandle
          }
        ],
        operatorConfig: {
          fixed: 'right',
          label: '操作',
          width: 100,
          minWidth: 100
        }
      },
      unitList: [],
      materialTypeList: [],
      categoryList: [],
      assortmentList: [],
      lotTrackingIfsOptions: [
        { value: false, label: '否' },
        { value: true, label: '是' }
      ],
      planningMethodOptions: [],
      threeLevelClassificationOptions: []
    }
  },
  components: {
    TableForm,
    ttable
  },
  created() {
    this.getMaterialType('apply_report_type')
  },
  computed: {
    ...mapGetters(['permissions'])
  },
  methods: {
    // 获取数据列表
    getData() {
      this.$refs.detectionrulesTable.getDataList()
    },
    // 新增 / 修改
    addOrUpdateHandle(row) {
      this.addOrUpdateVisible = true
      this.$nextTick(() => {
        this.$refs.addOrUpdate.init(row == null ? null : row.id)
      })
    },
    // 删除
    deleteHandle(row) {
      this.$confirm('是否确认规则名为:' + row.ruleName, '提示', {
        confirmButtonText: '确定',
        cancelButtonText: '取消',
        closeOnClickModal: false,
        type: 'warning'
      })
        .then(function() {
          return delTestApplyRule(row.id)
        })
        .then((data) => {
          this.$message.success('删除成功')
          this.getData()
        })
    },
    getMaterialType(type) {
      remote(type).then((response) => {
        const code = response.data.code
        if (code === 0) {
          const _data = response.data.data
          this.materialTypeList = _data
        }
      })
    },
    getMaterialTypeType(row, column, cellValue) {
      this.materialTypeList.forEach((obj) => {
        if (obj.value == cellValue) {
          cellValue = obj.label
        }
      })
      return cellValue
    },
    // 零件类型下拉框查询
    getMaterialTypeList() {
      return this.materialTypeList
    },
    handleSelectionChange(val) {
      this.multipleSelection = val
    }
  }
}
</script>
